

.. _sphx_glr_auto_examples_realtime_analysis_event_dumper.py:


=================
Live Event Dumper
=================

Recieves triggered events from the detector and dumps them to a file.




.. code-block:: python

    from __future__ import absolute_import, print_function, division

    from km3pipe import Pipeline, Module
    from km3pipe.io.ch import CHPump
    from km3pipe.io.daq import DAQProcessor

    __author__ = 'Tamas Gal <tgal@km3net.de>'


    class Dumper(Module):
        def configure(self):
            self.counter = 0

        def process(self, blob):
            tag = str(blob['CHPrefix'].tag)
            data = blob['CHData']
            self.dump(data, tag)
            print(blob["Hits"])
            return blob

        def dump(self, data, tag):
            with open('{0}-{1:06}.dat'.format(tag, self.counter), 'bw') as f:
                self.counter += 1
                f.write(data)


    pipe = Pipeline()
    pipe.attach(
        CHPump,
        host='xxx.xxx.xxx.xxx',
        port=5553,
        tags='IO_EVT',
        timeout=60 * 60 * 24,
        max_queue=42)
    pipe.attach(DAQProcessor)
    pipe.attach(Dumper)
    pipe.drain()

**Total running time of the script:** ( 0 minutes  0.000 seconds)



.. only :: html

 .. container:: sphx-glr-footer


  .. container:: sphx-glr-download

     :download:`Download Python source code: event_dumper.py <event_dumper.py>`



  .. container:: sphx-glr-download

     :download:`Download Jupyter notebook: event_dumper.ipynb <event_dumper.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.readthedocs.io>`_
